==> dojo-1.9.4.tgz: package/cldr/nls/zh-hant/gregorian.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "週天",
	"dateFormatItem-yQQQ": "y年QQQ",
	"dateFormatItem-yMEd": "y/M/d（E）",
	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
	"dateFormatItem-MMMEd": "M月d日E",
	"eraNarrow": [
		"西元前",
		"西元"
	],
	"dateFormatItem-yMM": "y-MM",
	"dayPeriods-format-wide-earlyMorning": "清晨",
	"dayPeriods-format-wide-morning": "上午",
	"days-format-short": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dateFormat-long": "y年M月d日",
	"months-format-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "下午",
	"dateFormat-full": "y年M月d日EEEE",
	"dateFormatItem-Md": "M/d",
	"dayPeriods-format-narrow-midDay": "中午",
	"dayPeriods-format-wide-noon": "中午",
	"dateFormatItem-yMd": "y/M/d",
	"field-era": "年代",
	"dateFormatItem-yM": "y/M",
	"months-standAlone-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"timeFormat-short": "ah:mm",
	"quarters-format-wide": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"dateFormatItem-yQQQQ": "y年QQQQ",
	"timeFormat-long": "zah時mm分ss秒",
	"field-year": "年",
	"dateFormatItem-yMMM": "y年M月",
	"field-hour": "小時",
	"dateFormatItem-MMdd": "MM/dd",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"timeFormat-full": "zzzzah時mm分ss秒",
	"dayPeriods-format-narrow-morning": "上午",
	"field-day-relative+0": "今天",
	"field-day-relative+1": "明天",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"field-day-relative+2": "後天",
	"dateFormatItem-H": "H時",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"quarters-format-abbr": [
		"1季",
		"2季",
		"3季",
		"4季"
	],
	"quarters-standAlone-wide": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"dateFormatItem-Gy": "Gy年",
	"dateFormatItem-M": "M月",
	"timeFormat-medium": "ah:mm:ss",
	"dateFormatItem-Hm": "H:mm",
	"quarters-standAlone-abbr": [
		"1季",
		"2季",
		"3季",
		"4季"
	],
	"eraAbbr": [
		"西元前",
		"西元"
	],
	"field-minute": "分鐘",
	"field-dayperiod": "上午/下午",
	"days-standAlone-abbr": [
		"週日",
		"週一",
		"週二",
		"週三",
		"週四",
		"週五",
		"週六"
	],
	"dayPeriods-format-wide-night": "晚上",
	"dateFormatItem-d": "d日",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "昨天",
	"dateFormatItem-h": "ah時",
	"dateTimeFormat-long": "{1}{0}",
	"dayPeriods-format-narrow-am": "上午",
	"field-day-relative+-2": "前天",
	"dateFormatItem-MMMd": "M月d日",
	"dayPeriods-format-wide-midDay": "中午",
	"dateFormatItem-MEd": "M/d（E）",
	"dateTimeFormat-full": "{1}{0}",
	"dateFormatItem-yMMMM": "y年M月",
	"field-day": "日",
	"days-format-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"field-zone": "時區",
	"dateFormatItem-y": "y年",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year-relative+-1": "去年",
	"dayPeriods-format-narrow-night": "晚上",
	"field-month-relative+-1": "上個月",
	"dateFormatItem-hm": "ah:mm",
	"dayPeriods-format-narrow-weeHours": "凌晨",
	"days-format-abbr": [
		"週日",
		"週一",
		"週二",
		"週三",
		"週四",
		"週五",
		"週六"
	],
	"dateFormatItem-yMMMd": "y年M月d日",
	"eraNames": [
		"西元前",
		"西元"
	],
	"dayPeriods-format-narrow-earlyMorning": "清晨",
	"days-standAlone-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "月",
	"dayPeriods-format-wide-am": "上午",
	"dateFormatItem-MMMMdd": "M月dd日",
	"dayPeriods-format-wide-weeHours": "凌晨",
	"dateFormat-short": "y/M/d",
	"dayPeriods-format-wide-afternoon": "下午",
	"dayPeriods-format-narrow-afternoon": "下午",
	"dayPeriods-format-narrow-noon": "中午",
	"field-second": "秒",
	"dateFormatItem-yMMMEd": "y年M月d日E",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下個月",
	"dateFormatItem-Ed": "d日（E）",
	"field-week": "週",
	"dateFormat-medium": "y/M/d",
	"field-year-relative+0": "今年",
	"field-week-relative+-1": "上週",
	"field-year-relative+1": "明年",
	"dayPeriods-format-narrow-pm": "下午",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "H:mm:ss",
	"dateFormatItem-hms": "ah:mm:ss",
	"dateFormatItem-GyMMM": "Gy年M月",
	"field-week-relative+0": "本週",
	"field-week-relative+1": "下週"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/zh-hant/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E a h:mm",
	"days-standAlone-short": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-second-relative+0": "現在",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "週天",
	"dateFormatItem-yQQQ": "y年QQQ",
	"dateFormatItem-yMEd": "y/M/d（E）",
	"field-wed-relative+0": "本週三",
	"dateFormatItem-GyMMMEd": "Gy年M月d日 E",
	"dateFormatItem-MMMEd": "M月d日 E",
	"field-wed-relative+1": "下週三",
	"eraNarrow": [
		"西元前",
		"公元前",
		"西元",
		"公元"
	],
	"dateFormatItem-yMM": "y-MM",
	"dayPeriods-format-wide-earlyMorning": "清晨",
	"field-tue-relative+-1": "上週二",
	"dayPeriods-format-wide-morning": "上午",
	"days-format-short": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dateFormat-long": "y年M月d日",
	"field-fri-relative+-1": "上週五",
	"field-wed-relative+-1": "上週三",
	"months-format-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "下午",
	"dateFormat-full": "y年M月d日 EEEE",
	"field-thu-relative+-1": "上週四",
	"dateFormatItem-Md": "M/d",
	"dayPeriods-format-narrow-midDay": "中午",
	"dayPeriods-format-wide-noon": "中午",
	"dateFormatItem-yMd": "y/M/d",
	"dateFormatItem-yM": "y/M",
	"field-era": "年代",
	"months-standAlone-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"timeFormat-short": "ah:mm",
	"quarters-format-wide": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"timeFormat-long": "ah:mm:ss [z]",
	"dateFormatItem-yMMM": "y年M月",
	"dateFormatItem-yQQQQ": "y年QQQQ",
	"field-year": "年",
	"dateFormatItem-MMdd": "MM/dd",
	"field-hour": "小時",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-sat-relative+0": "本週六",
	"field-sat-relative+1": "下週六",
	"timeFormat-full": "ah:mm:ss [zzzz]",
	"dayPeriods-format-narrow-morning": "上午",
	"field-day-relative+0": "今天",
	"field-day-relative+1": "明天",
	"field-thu-relative+0": "本週四",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"field-day-relative+2": "後天",
	"field-thu-relative+1": "下週四",
	"dateFormatItem-H": "H時",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"quarters-format-abbr": [
		"1季",
		"2季",
		"3季",
		"4季"
	],
	"quarters-standAlone-wide": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"dateFormatItem-Gy": "Gy年",
	"dateFormatItem-M": "M月",
	"days-standAlone-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"timeFormat-medium": "ah:mm:ss",
	"field-sun-relative+0": "本週日",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"1季",
		"2季",
		"3季",
		"4季"
	],
	"field-sun-relative+1": "下週日",
	"eraAbbr": [
		"西元前",
		"西元"
	],
	"field-minute": "分鐘",
	"field-dayperiod": "上午/下午",
	"days-standAlone-abbr": [
		"週日",
		"週一",
		"週二",
		"週三",
		"週四",
		"週五",
		"週六"
	],
	"dayPeriods-format-wide-night": "晚上",
	"dateFormatItem-d": "d日",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "昨天",
	"dateFormatItem-h": "ah時",
	"dateTimeFormat-long": "{1} {0}",
	"dayPeriods-format-narrow-am": "上午",
	"field-day-relative+-2": "前天",
	"dateFormatItem-MMMd": "M月d日",
	"dayPeriods-format-wide-midDay": "中午",
	"dateFormatItem-MEd": "M/d（E）",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "本週五",
	"dateFormatItem-yMMMM": "y年M月",
	"field-fri-relative+1": "下週五",
	"field-day": "日",
	"days-format-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"field-zone": "時區",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"dateFormatItem-y": "y年",
	"field-year-relative+-1": "去年",
	"dayPeriods-format-narrow-night": "晚上",
	"field-month-relative+-1": "上個月",
	"dateFormatItem-hm": "ah:mm",
	"dayPeriods-format-narrow-weeHours": "凌晨",
	"days-format-abbr": [
		"週日",
		"週一",
		"週二",
		"週三",
		"週四",
		"週五",
		"週六"
	],
	"eraNames": [
		"西元前",
		"西元"
	],
	"dateFormatItem-yMMMd": "y年M月d日",
	"days-format-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dayPeriods-format-narrow-earlyMorning": "清晨",
	"days-standAlone-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "月",
	"field-tue-relative+0": "本週二",
	"field-tue-relative+1": "下週二",
	"dayPeriods-format-wide-am": "上午",
	"dateFormatItem-EHm": "E HH:mm",
	"dayPeriods-format-wide-weeHours": "凌晨",
	"dateFormatItem-MMMMdd": "M月dd日",
	"field-mon-relative+0": "本週一",
	"field-mon-relative+1": "下週一",
	"dateFormat-short": "y/M/d",
	"dayPeriods-format-wide-afternoon": "下午",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E a h:mm:ss",
	"dayPeriods-format-narrow-afternoon": "下午",
	"dayPeriods-format-narrow-noon": "中午",
	"field-second": "秒",
	"field-sat-relative+-1": "上週六",
	"dateFormatItem-yMMMEd": "y年M月d日 E",
	"field-sun-relative+-1": "上週日",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下個月",
	"dateFormatItem-Ed": "d日（E）",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "週",
	"dateFormat-medium": "y年M月d日",
	"field-year-relative+0": "今年",
	"field-week-relative+-1": "上週",
	"field-year-relative+1": "明年",
	"dayPeriods-format-narrow-pm": "下午",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "ah:mm:ss",
	"dateFormatItem-GyMMM": "Gy年M月",
	"field-mon-relative+-1": "上週一",
	"field-week-relative+0": "本週",
	"field-week-relative+1": "下週"
}
//end v1.x content
);
